#
# spec file for package dive
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           dive
Version:        0.13.1
Release:        1.1
Summary:        Tool for exploring each layer in a docker image
License:        MIT
URL:            https://github.com/wagoodman/dive
Source:         %{name}-%{version}.tar.gz
Source1:        vendor.tar.gz
BuildRequires:  go >= 1.19

%description
A tool for exploring a docker image, layer contents, and discovering ways to
shrink the size of your Docker/OCI image.

%prep
%autosetup -p 1 -a 1

%build
COMMIT_HASH="$(sed -n 's/commit: \(.*\)/\1/p' %_sourcedir/%{name}.obsinfo)"

DATE_FMT="+%%Y-%%m-%%dT%%H:%%M:%%SZ"
BUILD_DATE=$(date -u -d "@${SOURCE_DATE_EPOCH}" "${DATE_FMT}" 2>/dev/null || date -u -r "${SOURCE_DATE_EPOCH}" "${DATE_FMT}" 2>/dev/null || date -u "${DATE_FMT}")

go build \
   -mod=vendor \
   -buildmode=pie \
   -ldflags=" \
   -X main.version=v%{version} \
   -X main.commit=${COMMIT_HASH:0:8} \
   -X main.buildTime=${BUILD_DATE}" \
   -o bin/%{name}

%install
# Install the binary.
install -D -m 0755 bin/%{name} %{buildroot}/%{_bindir}/%{name}

%files
%doc README.md
%license LICENSE
%{_bindir}/%{name}

%changelog
* Sat Mar 29 2025 Johannes Kastl <opensuse_buildservice@ojkastl.de>
- Update to version 0.13.1:
  * Bug Fixes
  - Fix layer selection to select only one layer at a time [#585
    @wagoodman]
  - Gitlab-ci integration is broken with latest docker image
    [#580 #586 @wagoodman]
  - Failed to Create Container After Upgrading to 0.13.0 [#576
    [#586] @wagoodman]
  - exec: "getent": executable file not found in $PATH [#582 #586
    @wagoodman]
  - Publish dive to ghcr.io [#573 #577 @wagoodman]
  * Additional Changes
  - Add x-cmd method to install dive [#550 @lunrenyi]
* Fri Mar 21 2025 opensuse_buildservice@ojkastl.de
- Update to version 0.13.0:
  * Added Features
  - Add winget support [#346 @Okeanos]
  - Added ppc64le support [#551 @pooja0805]
  - Show setuid, setgid and sticky attributes [#524
    @AlexanderYastrebov]
  - Add layer-wise filesystem information to the analysis json
    file [#458 @Akash-Nayak]
  - Add vim like arrow, scroll, and close filtering motions [#129
    [#499] #501 @mehmetumit @gwendolyngoetz @joschi ]
  * Bug Fixes
  - Doesn't use socket from current docker context [#495 #412
    [#490] #570 @joschi @rajiv-k]
  - Does not work with colima engine [#397 #490 #570 @joschi
    @rajiv-k]
  - Document how to use dive with M1 and colima [#408 #490 #570
    @joschi @rajiv-k]
  - Layers panel doesn't scroll when many layers exist [#540 #473
    [#520] @mark2185 @pov1ba]
  - Layers pane doesn't scroll when navigating to layer below
    visible region [#469 #478 #473 #570 #522 @joschi @mark2185
    @moaimullet @st-gr]
  - Cannot scroll through layers [#494 #473 #521 #570 @joschi
    @mark2185 @st-gr]
  - Can't inspect docker:23.0.1 through podman [#475 #476 #570
    @joschi @abitrolly]
  - Docker containerd format fails to parse layers with dive
    0.12.0 [#510 @Maddog2050]
  - Cannot find 'blobs/sha256/...' in parsed layers using dive
    0.12.0 [#507 @Maddog2050]
  - Does not work with docker v26+ [#534 @Maddog2050]
  - Line wrap toggle does not update the status bar indicator
    [#496 #497 #570 @joschi @Scomocouk]
  - Close temp iid files used for docker and podman build [#517
    @testwill]
  * Additional Changes
  - Update dependencies [#535 @reneleonhardt]
  - Fix typos [#531 @kianmeng]
  - Make README.md installation commands easier to copy and paste
    [#506 @ames0k0]
  - Update the README go install command to the latest version
    [#509 @tgross35]
  - Remove repetitive words [#515 @thirdkeyword]
  - Fix phony ci-release target [#530 @st3iny]
  - Add warning message for snap installation approach on
    Ubuntu/Debian [#552 @YuanfengZhang]
  - Update curl commands used for installation with -f [#533
    @guoard]
  - Describe what "Fetching" is really doing [#482 @docwhat]
  - Login to GHCR as owner not actor [#574 @polarathene]
  - Update README.md with DOCKER_HOST env var instructions [#565
    @benjamin-brady]
* Mon Sep 23 2024 Johannes Kastl <opensuse_buildservice@ojkastl.de>
- new package dive: tool for exploring each layer in a docker image
